@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::Plugin::NextVersion::Semantic::AUTHORITY = 'cpan:YANICK';
 }
 # ABSTRACT: update the next version, semantic-wise
-$Dist::Zilla::Plugin::NextVersion::Semantic::VERSION = '0.2.3';
+$Dist::Zilla::Plugin::NextVersion::Semantic::VERSION = '0.2.4';
 use strict;
 use warnings;
 
@@ -199,7 +199,9 @@ sub increment_level {
 
     no warnings;
 
-    my $increment_level = min map { $category_map{$_} }
+    my $increment_level = min 
+        grep { defined } 
+        map  { $category_map{$_} }
         grep { scalar @{ $changelog->changes($_) } }  # only groups with items
         $changelog->groups;
 
@@ -233,7 +235,7 @@ no Moose;
 BEGIN {
   $Dist::Zilla::Plugin::NextVersion::Semantic::Incrementer::AUTHORITY = 'cpan:YANICK';
 }
-$Dist::Zilla::Plugin::NextVersion::Semantic::Incrementer::VERSION = '0.2.3';
+$Dist::Zilla::Plugin::NextVersion::Semantic::Incrementer::VERSION = '0.2.4';
 use List::AllUtils qw/ first_index any /;
 
     use Moose::Role;
@@ -312,7 +314,7 @@ Dist::Zilla::Plugin::NextVersion::Semantic - update the next version, semantic-w
 
 =head1 VERSION
 
-version 0.2.3
+version 0.2.4
 
 =head1 SYNOPSIS
 
